mime property

String? get mime

Computes the MIME type of this file by inspecting its header bytes.

This value is cached per access but recomputed each time.

Implementation

String? get mime => lookupMimeType(path);