applicationCachePath property
Absolute path to the application cache directory.
Use this for temporary files that can be safely deleted by the system.
Implementation
late final String applicationCachePath;
Absolute path to the application cache directory.
Use this for temporary files that can be safely deleted by the system.
late final String applicationCachePath;