DownloadErrorCode enum

Inheritance
Available extensions

Values

objectNotFound → const DownloadErrorCode

The requested object was not found in the remote storage.

bucketNotFound → const DownloadErrorCode

The specified storage bucket does not exist.

projectNotFound → const DownloadErrorCode

The Firebase project was not found or misconfigured.

quotaExceeded → const DownloadErrorCode

The storage quota for the project has been exceeded.

unauthenticated → const DownloadErrorCode

The user is not authenticated.

unauthorized → const DownloadErrorCode

The user does not have permission to access the file.

retryLimitExceeded → const DownloadErrorCode

The download has failed multiple times and exceeded retry limits.

canceled → const DownloadErrorCode

The download was canceled manually.

invalidChecksum → const DownloadErrorCode

The downloaded file's checksum did not match.

invalidUrl → const DownloadErrorCode

The requested URL was invalid or malformed.

invalidArgument → const DownloadErrorCode

The download was provided with an invalid argument.

networkError → const DownloadErrorCode

A network error occurred (e.g., no internet connection).

unknown → const DownloadErrorCode

An unknown error occurred.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<DownloadErrorCode>
A constant List of the values in this enum, in order of their declaration.