DownloadProgress class
Represents the current progress of an active download operation.
This model is typically emitted by the StorageDownload system to indicate
how much of a file has been downloaded so far. It includes:
- the remotePath of the file being downloaded,
- the progress as a value between
0.0and100.0(inclusive).
This class is commonly used for UI updates (e.g. progress bars), download tracking, or logs.
Example:
DownloadProgress(
remotePath: 'media/files/sample.pdf',
progress: 42.0,
);
Constructors
- DownloadProgress({required String remotePath, required double progress})
-
Represents the current progress of an active download operation.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- progress → double
-
The current progress of the download, from
0.0(not started) to100.0(fully downloaded).final -
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- remotePath → String
-
The full remote path of the file being downloaded.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited