ImageMedia class

Inheritance
Available extensions

Constructors

ImageMedia({required String resourceId, required String mime, required Path path, required bool synced, required int createdAt, required int updatedAt, required String blurhash, required int width, required int height, required int size})
const
ImageMedia.fromMap(Map<String, dynamic> map)
factory

Properties

blurhash String
A compact visual placeholder generated from the image (e.g. BlurHash).
final
companion → MediaTableCompanion

Available on Media, provided by the MediaCompanionExtension extension

no setter
createdAt int
finalinherited
hashCode int
The hash code for this object.
no setterinherited
height int
The original height of the image in pixels.
final
mime String
finalinherited
path Path
finalinherited
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
resourceId String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
finalinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
synced bool
finalinherited
type MediaType
no setteroverride
updatedAt int
finalinherited
width int
The original width of the image in pixels.
final

Methods

copyWith({String? resourceId, String? mime, Path? path, bool? synced, int? createdAt, int? updatedAt, String? blurhash, int? width, int? height, int? size}) ImageMedia
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited