MediaStat class

Constructors

MediaStat({required int audio, required int document, required int image, required int video})

Properties

audio int
final
document int
final
hashCode int
The hash code for this object.
no setterinherited
image int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
video int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited