VideoMedia class
- Inheritance
- Available extensions
Constructors
- VideoMedia({required String resourceId, required String mime, required Path path, required bool synced, required int createdAt, required int updatedAt, required int size, required String blurhash, required int width, required int height, required int duration, required int orientation})
-
const
-
VideoMedia.fromMap(Map<
String, dynamic> map) -
factory
Properties
- blurhash → String
-
A compact blur hash representation used for previewing the video.
final
- companion → MediaTableCompanion
-
Available on Media, provided by the MediaCompanionExtension extension
no setter - createdAt → int
-
finalinherited
- duration → int
-
The duration of the video in milliseconds.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → int
-
The original height of the video in pixels.
final
- mime → String
-
finalinherited
- orientation → int
-
The orientation of the video in degrees (e.g. 0, 90, 180, 270).
final
- path → Path
-
finalinherited
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- resourceId → String
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → int
-
finalinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - synced → bool
-
finalinherited
- type → MediaType
-
no setteroverride
- updatedAt → int
-
finalinherited
- width → int
-
The original width of the video in pixels.
final
Methods
-
copyWith(
{String? resourceId, String? mime, Path? path, bool? synced, int? createdAt, int? updatedAt, String? blurhash, int? width, int? height, int? duration, int? orientation, int? size}) → VideoMedia -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited