DocumentMedia class
- Inheritance
- Available extensions
Constructors
Properties
- companion → MediaTableCompanion
-
Available on Media, provided by the MediaCompanionExtension extension
no setter - createdAt → int
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- mime → String
-
finalinherited
- path → Path
-
finalinherited
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- resourceId → String
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → int
-
finalinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - synced → bool
-
finalinherited
- type → MediaType
-
no setteroverride
- updatedAt → int
-
finalinherited
Methods
-
copyWith(
{String? resourceId, Path? path, String? mime, bool? synced, int? createdAt, int? updatedAt, int? size}) → DocumentMedia -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited