Media class abstract

Implementers
Available extensions

Constructors

Media({required String resourceId, required Path path, required bool synced, required int createdAt, required int updatedAt, required String mime, required int size})
const

Properties

companion → MediaTableCompanion

Available on Media, provided by the MediaCompanionExtension extension

no setter
createdAt int
final
hashCode int
The hash code for this object.
no setterinherited
mime String
final
path Path
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setterinherited
resourceId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
final
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
synced bool
final
type MediaType
no setter
updatedAt int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromMap(Map<String, dynamic> map) Media